import { IController, IModel } from '../types/index';
/**
 * HTTP Controller Marker
 * @param resourcePath
 *  The path to the resource for default
 */
export declare const Controller: (resourcePath?: string) => (target: any) => void;
/**
 * HTTP POST Marker
 * @param path
 *  The path to the resource for default
 */
export declare const POST: (path?: string) => (target: any, propertyKey: string, descriptor: TypedPropertyDescriptor<any>) => void;
/**
 * HTTP GET Marker, Decorate the method with the GET Decorator
 * @param path
 *  The path to the resource for default
 */
export declare const GET: (path?: string) => (target: any, propertyKey: string, descriptor: TypedPropertyDescriptor<any>) => void;
/**
 * HTTP DELETE Marker
 * @param path
 *  The path to the resource for default
 */
export declare const DELETE: (path?: string) => (target: any, propertyKey: string, descriptor: TypedPropertyDescriptor<any>) => void;
/**
 * HTTP PUT Marker
 * @param path
 *  The path to the resource for default
 */
export declare const PUT: (path?: string) => (target: any, propertyKey: string, descriptor: TypedPropertyDescriptor<any>) => void;
/**
 * PathParam Setter/Marker
 * @param pathParam
 *  The path parameter from the Request
 */
export declare const PathParam: (pathParam: string) => (target: IController, propertyKey: string, parameterIndex: number) => void;
/**
 * Query Parameter Setter/Marker
 * @param queryParam
 *  The  query parameter from the Request
 */
export declare const QueryParam: (queryParam: string) => (target: IController, propertyKey: string, parameterIndex: number) => void;
/**
 * Mapper Decorator
 * @param type
 *    Decorate the Controller with the Model, which should use for the Mapper
 */
export declare const Model: <T extends IModel>(model: T) => (target: IModel) => void;
