/**
 * This class represent the http response object
 */
export default class Response {
    private statusCode;
    private headers;
    private body;
    /**
     * Generate success response for aws API gateway
     * @param body
     * Http response body object
     * @param statusCode
     * Http status code like 200, 204 etc
     * @return
     * Http response object as JSON string
     */
    getSuccessResponse(httpMethod: string, body?: Object): Object;
    /**
     * Generate error response for aws API gateway
     * @param error
     * Application error like 500, 400 etc
     * @return
     * Http response object as JSON string
     */
    getErrorResponse(error: Object): Object;
    /**
     * Set Response from the success body and
     * map http method to http status code
     * @param httpMethod
     * The httpMethod like GET, POST etc
     * @param body
     * Response body object
     */
    setSuccessResponse(httpMethod: string, body?: Object): void;
    /**
     * Set Response based on the error type and
     * map error to corresponding http status code
     * @param error
     * Application error
     */
    setErrorResponse(error: Object): void;
    /**
     * Convert Response object instance to JSON Object
     */
    toJSONObject(): Object;
}
